# Examples

This directory contains various product configuration examples encoded in the
[COOM language](https://coom-lang.org). They can be found in the
[`coom`](coom/) directory.

For illustration of the different COOM language fragments, we have various
examples of bike configurations in increasing complexity:

- [Kids Bike](coom/kids-bike.coom)
- [City Bike](coom/city-bike.coom)
- [Travel Bike](coom/travel-bike.coom)
- [Cargo Bike](coom/cargo-bike.coom)
